<?php
namespace Controller;

use Service\ErrorRepository as ErrorRepositoryService;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DTO\Request\Row as RequestRow;
use Zeedhi\Framework\DTO\Request\Filter as RequestFilter;
use Zeedhi\Framework\DTO\Request\DataSet as RequestDataset;

class ErrorRepository {
    private $errorRepService;

    public function __construct(ErrorRepositoryService $errorRepService) {
        $this->errorRepService = $errorRepService;
    }

    public function findErrorRepository(RequestFilter $request, Response $response){
        $conditions = $request->getFilterCriteria()->getConditions();
        $page       = $request->getFilterCriteria()->getPage();
        $pageSize   = $request->getFilterCriteria()->getPageSize();
        $result     = $this->errorRepService->findErrorRepository($conditions, $page, $pageSize);
        $response->addDataSet(new DataSet('errorRepository', $result));
    }

    public function saveErrorRepository(RequestDataset $request, Response $response) {
        try {
            $deployRows  = $request->getDataSet()->getRows();
            $deploy      = $deployRows[0];
            $id          = $deploy['ID'];
            $reason      = $deploy['REASON'];
            $resolution  = $deploy['RESOLUTION'];
            $description = $deploy['DESCRIPTION'];
            $type        = $deploy['TYPE'];
            $savedError  = $this->errorRepService->saveErrorRepository($id, $reason, $resolution, $description, $type);
            $response->addDataSet(new DataSet('savedErrorRepository', $savedError));
        } catch (\Exception $e) {
            $response->addMessage(new Response\Message($e->getMessage(), Response\Message::TYPE_ERROR));
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }

    public function deleteErrorRepository(RequestRow $request, Response $response){
        try {
            $row = $request->getRow();
            $id  = $row["ID"];
            $this->errorRepService->deleteError($id);
        } catch (\Exception $e){
            $response->addMessage(new Response\Message($e->getMessage(), Response\Message::TYPE_WARNING));
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }

}